@@ -2,9 +2,13 @@
 # See LICENSE for details.
 
 __author__ = "Thinh Vu @thinh-vu in GitHub"
-__version__ = "0.0.1"
+__version__ = "0.0.3"
 
-from .utils import *
-from .wordcloud import *
 from .ebook import *
-from .markdown import *
\ No newline at end of file
+from .gpt_model import *
+from .markdown import *
+from .ocr import *
+from .text_preprocessing import *
+from .utils import *
+from .web2text import *
+from .wordcloud import *
\ No newline at end of file
